Fast generators and iterators for permutations, combinations, integer partitions and compositions. The arrangements are in lexicographical order and generated iteratively in a memory efficient manner. It has been demonstrated that 'arrangements' outperforms most existing packages of similar kind. Benchmarks could be found at https://randy3k.github.io/arrangements/articles/benchmark.html.

Author

Maintainer: Randy Lai randy.cs.lai@gmail.com